/**
 * OW2 Util
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: CommonClassMetadataConfigurator.java 6281 2012-08-30 09:52:45Z albertil $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator;

import java.util.List;
import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationResourcesVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSecurityRunAs;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxAnnotationSqlDataSourceDefinitionsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxEjbEJBsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceContextsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxPersistencePersistenceUnitsVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz.JavaxXmlWsWebServiceRefsVisitor;
import org.ow2.util.scan.api.configurator.metadata.ClassMetadataConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificArchiveConfigurator;

/**
 * CommonClassMetadataConfigurator.
 * @author Gael Lalire
 * @param <C> class type
 * @param <M> method type
 * @param <F> field type
 */
public abstract class CommonClassMetadataConfigurator<
    C extends ICommonClassMetadata<C, M, F>,
    M extends ICommonMethodMetadata<C, M, F>,
    F extends ICommonFieldMetadata<C, M, F>>
        extends ClassMetadataConfigurator<C, M, F> {

    /**
     * Constructor.
     * @param classMetadata classMetadata
     * @param specificArchiveConfiguratorList specific archive configurator list
     */
    public CommonClassMetadataConfigurator(final C classMetadata,
            final List<? extends ISpecificArchiveConfigurator<C, M, F>> specificArchiveConfiguratorList) {
        super(classMetadata, specificArchiveConfiguratorList);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {

        C classMetadata = getClassMetadata();

        // add visitor shared with class and field and method
        CommonMetadataConfigurator.initVisitor(getAnnotationVisitors(), classMetadata);

        // add @EJBs
        getAnnotationVisitors().put(JavaxEjbEJBsVisitor.TYPE,
                new JavaxEjbEJBsVisitor(classMetadata));

        // add @Resources
        getAnnotationVisitors().put(JavaxAnnotationResourcesVisitor.TYPE,
                new JavaxAnnotationResourcesVisitor(classMetadata));

        // add @DataSourceDefinition
        getAnnotationVisitors().put(JavaxAnnotationSqlDataSourceDefinitionVisitor.TYPE,
                new JavaxAnnotationSqlDataSourceDefinitionVisitor<C, M, F>(classMetadata));

        // add @DataSourceDefinitions
        getAnnotationVisitors().put(JavaxAnnotationSqlDataSourceDefinitionsVisitor.TYPE,
                new JavaxAnnotationSqlDataSourceDefinitionsVisitor<C, M, F>(classMetadata));

        // add @PersistenceContexts
        getAnnotationVisitors().put(JavaxPersistencePersistenceContextsVisitor.TYPE,
                new JavaxPersistencePersistenceContextsVisitor(classMetadata));

        // add @PersistenceUnits
        getAnnotationVisitors().put(JavaxPersistencePersistenceUnitsVisitor.TYPE,
                new JavaxPersistencePersistenceUnitsVisitor(classMetadata));

        // add @WebServiceRefs
        getAnnotationVisitors().put(JavaxXmlWsWebServiceRefsVisitor.TYPE,
                                    new JavaxXmlWsWebServiceRefsVisitor(classMetadata));

        // add @RunAs
        getAnnotationVisitors().put(JavaxAnnotationSecurityRunAs.TYPE,
                new JavaxAnnotationSecurityRunAs<C, M, F>(classMetadata));

    }

}
