/*
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxAnnotationSqlDataSourceDefinitionsVisitor.java 6281 2012-08-30 09:52:45Z albertil $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AbsAnnotationVisitor;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.scan.api.IAnnotationVisitor;

/**
 * This class manages the handling of &#64;{@link javax.annotation.sql.DataSourceDefinitions} annotation.
 *
 * @param <T> An implementation of IJAnnotationSqlDataSourceDefinition interface.
 *
 * @author Loic Albertin
 */
public class JavaxAnnotationSqlDataSourceDefinitionsVisitor<
    T extends ICommonClassMetadata<T, M, F>,
    M extends ICommonMethodMetadata<T, M, F>,
    F extends ICommonFieldMetadata<T, M, F>>
    extends AbsAnnotationVisitor<T> implements AnnotationType {

    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/sql/DataSourceDefinitions;";


    /**
     * Constructor.
     *
     * @param annotationMetadata linked to a class or method metadata
     */
    public JavaxAnnotationSqlDataSourceDefinitionsVisitor(final T annotationMetadata) {
        super(annotationMetadata);
    }

    @Override
    public IAnnotationVisitor visitAnnotation(String name, String desc) {
        if (JavaxAnnotationSqlDataSourceDefinitionVisitor.TYPE.equals(desc)) {
            return new JavaxAnnotationSqlDataSourceDefinitionVisitor<T, M, F>(getAnnotationMetadata());
        }
        return super.visitAnnotation(name, desc);
    }

    /**
     * Visits the end of the annotation. <br>
     * Creates the object and store it.
     */
    @Override
    public void visitEnd() {
     //Noting to do every things are done by JavaxAnnotationSqlDataSourceDefinitionVisitor
    }

    /**
     * @return type of the annotation (its description)
     */
    public String getType() {
        return TYPE;
    }

}
